Struct Texture

pub struct Texture { /* private fields */ }

Implementations

Source

impl Texture

pub fn new(params: TextureParameters) -> Result<Self>

Allocate a new texture with the given parameters. Texture allocation can fail if the texture size specified by the parameters is too small or large, or memory allocation fails.

pub fn load_image(&mut self, data: &[u8], face: Face) -> Result<()>

Upload the provided data buffer to the texture, and to the given face if it’s a cube texture. For flat textures, the face argument is not considered so Face::default() can be used.

pub fn load_image_at_mipmap_level( &mut self, data: &[u8], face: Face, mipmap_level: u8, ) -> Result<()>

Upload the provided data buffer to the texture’s specific mipmap level, and to the given face if it’s a cube texture. For flat textures, the face argument is not considered so Face::default() can be used.

pub fn generate_mipmap(&mut self, face: Face)

Generate a mipmap for this texture, and this face if it’s a cube texture. For flat textures Face::default() or Face::TEX2D can be used.

pub fn set_filter(&mut self, mag_filter: Filter, min_filter: Filter)

pub fn set_filter_mipmap(&mut self, filter: Filter)

pub fn set_wrap(&mut self, wrap_s: Wrap, wrap_t: Wrap)

pub fn set_lod_bias(&mut self, lod_bias: f32)

pub fn width(&self) -> u16

pub fn height(&self) -> u16

pub fn param(&self) -> u32

pub fn format(&self) -> ColorFormat

pub fn lod_bias(&self) -> u16

pub fn max_level(&self) -> u8

pub fn min_level(&self) -> u8